@@ -174,7 +174,7 @@ class TICA(StreamingEstimationTransformer, SerializableMixIn):
     def describe(self):
         try:
             dim = self.dimension()
-        except AttributeError:
+        except RuntimeError:
             dim = self.dim
         return "[TICA, lag = %i; max. output dim. = %i]" % (self._lag, dim)
 
@@ -234,7 +234,7 @@ class TICA(StreamingEstimationTransformer, SerializableMixIn):
         The projection matrix is first being calculated upon its first access.
         """
         from pyemma.coordinates import source
-        iterable = source(X)
+        iterable = source(X, chunksize=self.chunksize)
 
         indim = iterable.dimension()
         if not self.dim <= indim:
@@ -265,9 +265,8 @@ class TICA(StreamingEstimationTransformer, SerializableMixIn):
 
         if self._logger_is_active(self._loglevel_DEBUG):
             self.logger.debug("Running TICA with tau=%i; Estimating two covariance matrices"
-                               " with dimension (%i, %i)", self._lag, indim, indim)
-
-        covar.estimate(iterable, **kw)
+                              " with dimension (%i, %i)", self._lag, indim, indim)
+        covar.estimate(iterable, chunksize=self.chunksize, **kw)
         self._model.update_model_params(mean=covar.mean,
                                         cov=covar.C00_,
                                         cov_tau=covar.C0t_)
